@@ -1,6 +1,6 @@
 package Lab::Measurement::DocWriter::HTML;
 #ABSTRACT: HTML documentation output for Lab::Measurement
-$Lab::Measurement::DocWriter::HTML::VERSION = '0.993';
+$Lab::Measurement::DocWriter::HTML::VERSION = '1.000';
 use strict;
 use parent 'Lab::Measurement::DocWriter';
 use File::Basename;
@@ -38,11 +38,11 @@ sub process_element {
     # my $basename = fileparse($podfile,qr{\.(pod|pm)});
 
     my $basename = $podfile; 
-    $basename =~ s!^.*/lib/Lab/!!g ;
+    $basename =~ s!^.*lib/!!g ;
     $basename =~ s!\.(pod|pm)!!g ;
     $basename =~ s!^.*Measurement/scripts/!!g ;
+    $basename =~ s!^examples/!!g ;
     $basename =~ s!/!-!g ;
-    $basename =~ s!VISA-VISA!VISA!g ;
 
     my $hascode = ($podfile =~ /\.(pl|pm)$/);
     print "pod $podfile base $basename\n";    
@@ -129,7 +129,7 @@ FOOTER
 
 
 package Lab::Measurement::DocWriter::HTML::MyPodXHTML;
-$Lab::Measurement::DocWriter::HTML::MyPodXHTML::VERSION = '0.993';
+$Lab::Measurement::DocWriter::HTML::MyPodXHTML::VERSION = '1.000';
 use strict;
 use parent 'Pod::Simple::XHTML';
 #use HTML::Entities;
@@ -148,7 +148,6 @@ sub resolve_pod_page_link {
     return undef unless defined $to || defined $section;
     if ($to =~ /^Lab/) {
         my $tg=$to;
-        $tg =~ s!^Lab::!!g ;
 	$tg =~ s!::!-!g ;
         return "$tg.html";
     }
@@ -179,7 +178,7 @@ Lab::Measurement::DocWriter::HTML - HTML documentation output for Lab::Measureme
 
 =head1 VERSION
 
-version 0.993
+version 1.000
 
 =head1 COPYRIGHT AND LICENSE
 
